@@ -122,30 +122,30 @@ class PlayerHome(gym.Env):
             skip = False
             if state in self.home.optimal_vals.keys():
                 obs += [self.home.optimal_vals[state]]
-            elif state == "leaving_horizon":
-                obs += [self.home.optimal_vals[state]]
-            elif state == "returning_horizon":
-                obs += [self.home.ev.index_5pm[0] if self.home.ev.index_5pm else -1]
+            # elif state == "leaving_horizon":
+                # obs += [self.home.ev.index_8am[0] if self.home.ev.index_8am else -1]
+            # elif state == "returning_horizon":
+                # obs += [self.home.ev.index_5pm[0] if self.home.ev.index_5pm else -1]
             elif state == "occupancy_status":
                 obs += [int(self.home.occ_on[0])]
             elif state == "future_waterdraws":
-                obs += [np.sum(self.home.optimal_vals["waterdraws"]) / self.home.wh.wh_size]
+                obs += [np.sum(self.home.optimal_vals["waterdraws"])]
             elif state == "t_out":
-                obs += [(self.home.all_oat[self.home.start_slice] - np.min(self.home.all_oat)) / (np.max(self.home.all_oat) - np.min(self.home.all_oat))]
+                obs += [self.home.all_oat[self.home.start_slice]]
             elif state == "t_out_6hr":
-                obs += [(self.home.all_oat[self.home.start_slice + 6*self.home.dt] - np.min(self.home.all_oat)) / (np.max(self.home.all_oat) - np.min(self.home.all_oat))]
+                obs += [self.home.all_oat[self.home.start_slice + 6*self.home.dt]]
             elif state == "t_out_12hr":
-                obs += [(self.home.all_oat[self.home.start_slice + 12*self.home.dt] - np.min(self.home.all_oat)) / (np.max(self.home.all_oat) - np.min(self.home.all_oat))]
+                obs += [self.home.all_oat[self.home.start_slice + 12*self.home.dt]]
             elif state == "ghi":
-                obs += [self.home.all_ghi[self.home.start_slice] / np.max(self.home.all_ghi)]
+                obs += [self.home.all_ghi[self.home.start_slice]]
             elif state == "ghi_6hr":
-                obs += [self.home.all_ghi[self.home.start_slice + 6*self.home.dt] / np.max(self.home.all_ghi)]
+                obs += [self.home.all_ghi[self.home.start_slice + 6*self.home.dt]]
             elif state == "ghi_12hr":
-                obs += [self.home.all_ghi[self.home.start_slice + 12*self.home.dt] / np.max(self.home.all_ghi)]
+                obs += [self.home.all_ghi[self.home.start_slice + 12*self.home.dt]]
             elif state == "t_in":
-                obs += [(self.home.optimal_vals["temp_in_opt"] - self.home.hvac.t_in_min_current.value[0]) / (self.home.hvac.t_in_max_current.value[0] - self.home.hvac.t_in_min_current.value[0])]
+                obs += [self.home.optimal_vals["temp_in_opt"]]
             elif state == "t_wh":
-                obs += [(self.home.optimal_vals["temp_wh_opt"] - self.home.wh.temp_wh_min.value )/(self.home.wh.temp_wh_max.value - self.home.wh.temp_wh_min.value)]
+                obs += [self.home.optimal_vals["temp_wh_opt"]]
             elif state == "e_ev":
                 obs += [self.home.optimal_vals["e_ev_opt"]]
             elif state == "time_of_day":
@@ -201,7 +201,7 @@ class PlayerHome(gym.Env):
 
         self.home.log = pathos.logger(level=logging.INFO, handler=fh, name=self.name)
 
-        self.redis_client = rc.connection(self.redis_url)#RedisClient()
+        self.redis_client = rc.connection(self.redis_url)
         self.home.redis_get_initial_values()
         self.home.cast_redis_timestep()
 
@@ -209,20 +209,16 @@ class PlayerHome(gym.Env):
             self.home.redis_get_prev_optimal_vals()
 
         self.home.get_initial_conditions()
-
         self.home.add_base_constraints()
         if action is not None:
-            if "ev_charge" in self.actions:
+            if "ev_charge" in self.actions and "ev" in self.home.devices:
                 self.home.ev.override_charge(action[-1]) # overrides the p_ch for the electric vehicle
                 action = action[:-1]
-            if "wh_setpoint" in self.actions:
-                # wh_action = self.wh_min + action[-1] * (self.wh_max - self.wh_min)
+            if "wh_setpoint" in self.actions and "wh" in self.home.devices:
                 self.home.wh.override_p_wh(action[-1]) # same but for waterheater
                 action = action[:-1]
-            if "hvac_setpoint" in self.actions:
-                # hvac_action = self.hvac_min + action[-1] * (self.hvac_max - self.hvac_min)
+            if "hvac_setpoint" in self.actions and "hvac" in self.home.devices:
                 self.home.hvac.override_t_in(action[-1]) # changes thermal deadband to new lower/upper bound
-        
         self.home.set_p_grid()
         self.home.solve_mpc(debug=True)
         self.home.cleanup_and_finish()
@@ -233,9 +229,9 @@ class PlayerHome(gym.Env):
         asyncio.run(self.post_status("updated"))
         asyncio.run(self.await_status("forward"))
 
-        self.demand_profile += [self.home.stored_optimal_vals["p_grid_opt"]]
+        self.demand_profile += [self.home.optimal_vals["p_grid_opt"]]
 
-        return self.get_obs(), self.get_reward(), False, {}
+        return self.get_obs() #, self.get_reward(), False, {}
 
     async def await_status(self, status):
         """
